<?php

namespace Drupal\menu_manipulator\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure custom settings for Menu Manipulators.
 */
class MenuManipulatorSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'menu_manipulator_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'menu_manipulator.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('menu_manipulator.settings');

    // Quick intro.
    $form['intro'] = [
      '#type' => 'markup',
      '#markup' => '<p>' . t('Configure custom Menu Manipulator settings here.') . '</p>',
      '#weight' => 0,
    ];

    // Settings.
    $form['settings'] = [
      '#type' => 'details',
      '#open' => TRUE,
      '#title' => t('Settings'),
      '#weight' => 0,
    ];  
    $form['settings']['preprocess_menus_title'] = [
      '#type' => 'checkbox',
      '#title' => t("Add menus' title in Twig"),
      '#description' => t('You can then use {{ menu_title }} in your menu.html.twig files.'),
      '#default_value' => $config->get('preprocess_menus_title'),
      '#weight' => 0,
    ];
    $form['settings']['preprocess_menus_language'] = [
      '#type' => 'checkbox',
      '#title' => t("Automatically filter menus by current's user language"),
      '#default_value' => $config->get('preprocess_menus_language'),
      '#weight' => 1,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $exclude = ['submit', 'form_build_id', 'form_token', 'form_id', 'op'];
    $config = \Drupal::configFactory()->getEditable('menu_manipulator.settings');
    foreach ($form_state->getValues() as $key => $data) {
      if (!in_array($key, $exclude)) {
        $config->set($key, $data);
      }
    }
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
